package org.xesstandard.extensions;

import java.net.URI;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesComponent;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.XesLog;
import org.xesstandard.model.XesTrace;
import org.xesstandard.model.attributes.XesStringAttribute;
import org.xesstandard.model.attributes.impl.XesStringAttributeImpl;
import org.xesstandard.model.impl.XesExtensionImpl;

public class XesConceptExtension extends XesExtensionImpl {

	public final static String NAME = "concept:name";
	public final static String INSTANCE = "concept:instance";

	private final static XesConceptExtension singleton = new XesConceptExtension();

	private XesConceptExtension() {
		super(true);
		setName("Concept");
		setPrefix("concept");
		try {
			setURI(new URI("http://www.xes-standard.org/concept.xesext"));
		} catch (Exception e) {
			System.err.println(e.getMessage());
		}

		XesAttribute attribute = new XesStringAttributeImpl();
		attribute.setKey(NAME);
		addLogAttribute(attribute);
		addTraceAttribute(attribute);
		addEventAttribute(attribute);
		addAlias(attribute, "EN", "Name");
		addAlias(attribute, "DE", "Name");
		addAlias(attribute, "FR", "Appelation");
		addAlias(attribute, "ES", "Nombre");
		addAlias(attribute, "PT", "Nome");

		attribute = new XesStringAttributeImpl();
		attribute.setKey(INSTANCE);
		addEventAttribute(attribute);
		addAlias(attribute, "EN", "Instance");
		addAlias(attribute, "DE", "Instanz");
		addAlias(attribute, "FR", "Entit\u00e9");
		addAlias(attribute, "ES", "Instancia");
		addAlias(attribute, "PT", "Inst\u00e2ncia");
	}

	/**
	 * @return The single instance of this extension.
	 */
	public static XesConceptExtension instance() {
		return singleton;
	}

	/**
	 * Returns the name of the given log, that is, the value of the attribute
	 * with key "concept:name".
	 * 
	 * @param log
	 *            The given log.
	 * @return The name of the given log.
	 */
	public String getName(XesLog log) {
		return log.getString(NAME);
	}

	private XesStringAttribute setString(XesComponent component, String key, String value) {
		XesStringAttribute attribute = new XesStringAttributeImpl();
		attribute.setKey(key);
		attribute.setValue(value);
		component.addAttribute(attribute);
		return attribute;
	}
	
	/**
	 * Sets the name for the given log, that is, the value of the attribute with
	 * key "concept:name".
	 * 
	 * @param log
	 *            The given log.
	 * @param value
	 *            The name to set.
	 * @return The attribute containing the name.
	 */
	public XesStringAttribute setName(XesLog log, String value) {
		return setString(log, NAME, value);
	}

	/**
	 * Returns the name of the given trace, that is, the value of the attribute
	 * with key "concept:name".
	 * 
	 * @param trace
	 *            The given trace.
	 * @return The name of the given trace.
	 */
	public String getName(XesTrace trace) {
		return trace.getString(NAME);
	}

	/**
	 * Sets the name for the given trace, that is, the value of the attribute
	 * with key "concept:name".
	 * 
	 * @param trace
	 *            The given trace.
	 * @param value
	 *            The name to set.
	 * @return The attribute containing the name.
	 */
	public XesStringAttribute setName(XesTrace trace, String value) {
		return setString(trace, NAME, value);
	}

	/**
	 * Returns the name of the given event, that is, the value of the attribute
	 * with key "concept:name".
	 * 
	 * @param event
	 *            The given event.
	 * @return The name of the given event.
	 */
	public String getName(XesEvent event) {
		return event.getString(NAME);
	}

	/**
	 * Sets the name for the given event, that is, the value of the attribute
	 * with key "concept:name".
	 * 
	 * @param event
	 *            The given event.
	 * @param value
	 *            The name to set.
	 * @return The attribute containing the name.
	 */
	public XesStringAttribute setName(XesEvent event, String value) {
		return setString(event, NAME, value);
	}

	/**
	 * Returns the instance of the given event, that is, the value of the
	 * attribute with key "concept:instance".
	 * 
	 * @param event
	 *            The given event.
	 * @return The instance of the given event.
	 */
	public String getInstance(XesEvent event) {
		return event.getString(INSTANCE);
	}

	/**
	 * Sets the instance for the given event, that is, the value of the
	 * attribute with key "concept:instance".
	 * 
	 * @param event
	 *            The given event.
	 * @param value
	 *            The instance to set.
	 * @return The attribute containing the instance.
	 */
	public XesStringAttribute setInstance(XesEvent event, String value) {
		return setString(event, INSTANCE, value);
	}
	
}
