package org.xesstandard.model.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesClassifier;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.XesExtension;
import org.xesstandard.model.XesLog;
import org.xesstandard.model.XesTrace;

public class XesLogImpl extends XesComponentImpl implements XesLog {

	/*
	 * Extensions of the log.
	 */
	private Map<String, XesExtension> extensions = new HashMap<String, XesExtension>();
	
	/*
	 * Global trace attributes of the log.
	 */
	private List<XesAttribute> globalTraceAttributes = new ArrayList<XesAttribute>();
	
	/*
	 * Global event attributes of the log.
	 */
	private List<XesAttribute> globalEventAttributes = new ArrayList<XesAttribute>();
	
	/*
	 * Trace classifiers of the log.
	 */
	private List<XesClassifier> traceClassifiers = new ArrayList<XesClassifier>();
	
	/*
	 * Event classifiers of the log.
	 */
	private List<XesClassifier> eventClassifiers = new ArrayList<XesClassifier>();
	
	/*
	 * Traces of the log.
	 */
	private List<XesTrace> traces = new ArrayList<XesTrace>();
	
	/*
	 * Events of the log (these events have the log as parent, and not a trace).
	 */
	private List<XesEvent> events = new ArrayList<XesEvent>();
	
	/*
	 * Version of XES used by the log.
	 */
	private String version = null;
	
	/*
	 * Features declared by the log.
	 */
	private List<String> features = new ArrayList<String>();
	
	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addExtension(org.xesstandard.model.XesExtension)
	 */
	public void addExtension(XesExtension extension) {
		extensions.put(extension.getPrefix(), extension);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getExtensions()
	 */
	public List<XesExtension> getExtensions() {
		return new ArrayList<XesExtension>(extensions.values());
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getExtension(java.lang.String)
	 */
	public XesExtension getExtension(String prefix) {
		return extensions.get(prefix);
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addGlobalTraceAttribute(org.xesstandard.model.XesAttribute)
	 */
	public void addGlobalTraceAttribute(XesAttribute attribute) {
		globalTraceAttributes.add(attribute);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getGlobalTraceAttributes()
	 */
	public List<XesAttribute> getGlobalTraceAttributes() {
		return globalTraceAttributes;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addGlobalEventAttribute(org.xesstandard.model.XesAttribute)
	 */
	public void addGlobalEventAttribute(XesAttribute attribute) {
		globalEventAttributes.add(attribute);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getGlobalEventAttributes()
	 */
	public List<XesAttribute> getGlobalEventAttributes() {
		return globalEventAttributes;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addTraceClassifier(org.xesstandard.model.XesClassifier)
	 */
	public void addTraceClassifier(XesClassifier classifier) {
		traceClassifiers.add(classifier);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getTraceClassifiers()
	 */
	public List<XesClassifier> getTraceClassifiers() {
		return traceClassifiers;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addEventClassifier(org.xesstandard.model.XesClassifier)
	 */
	public void addEventClassifier(XesClassifier classifier) {
		eventClassifiers.add(classifier);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getEventClassifiers()
	 */
	public List<XesClassifier> getEventClassifiers() {
		return eventClassifiers;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addTrace(org.xesstandard.model.XesTrace)
	 */
	public void addTrace(XesTrace trace) {
		traces.add(trace);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getTraces()
	 */
	public List<XesTrace> getTraces() {
		return traces;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addEvent(org.xesstandard.model.XesEvent)
	 */
	public void addEvent(XesEvent event) {
		events.add(event);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getEvents()
	 */
	public List<XesEvent> getEvents() {
		return events;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#setVersion(java.lang.String)
	 */
	public void setVersion(String version) {
		this.version = version ;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getVersion()
	 */
	public String getVersion() {
		return version;
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#addFeature(java.lang.String)
	 */
	public void addFeature(String feature) {
		features.add(feature);
	}

	/*
	 * (non-Javadoc)
	 * @see org.xesstandard.model.XesLog#getFeatures()
	 */
	public List<String> getFeatures() {
		return features;
	}

	public String toString() {
		return super.toString();
	}
}
