package org.xesstandard.xml.issues;

import java.util.List;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesClassifier;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.XesExtension;
import org.xesstandard.model.XesGlobal;
import org.xesstandard.model.XesTrace;
import org.xesstandard.model.attributes.XesListAttribute;
import org.xesstandard.xml.XesXmlIssueLevel;

public class XesXmlIssueOutOfPlace extends XesAbstractXmlIssue {

	/**
	 * Issue raised when two elements appear in the wrong order (like a trace before a classifier).
	 */
	private String precedingElement;
	private String element;
	
	public XesXmlIssueOutOfPlace(XesTrace trace) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Trace";
		this.element = "event";
	}
	
	public XesXmlIssueOutOfPlace(XesAttribute attribute, List<XesTrace> traces, List<XesEvent> events) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Attribute";
		this.element = "trace and event";
	}
	
	public XesXmlIssueOutOfPlace(XesAttribute attribute, List<XesEvent> events) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Attribute";
		this.element = "event";
	}
	
	public XesXmlIssueOutOfPlace(XesListAttribute attribute) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Attribute";
		this.element = "values";
	}
	
	public XesXmlIssueOutOfPlace(XesClassifier classifier) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Classifier";
		this.element = "attribute, trace and event";
	}
	
	public XesXmlIssueOutOfPlace(XesGlobal global) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Global";
		this.element = "classifier, attribute, trace and event";
	}
	
	public XesXmlIssueOutOfPlace(XesExtension extension) {
		super(XesXmlIssueLevel.CONFORMING);
		this.precedingElement = "Extension";
		this.element = "global, classifier, attribute, trace and event";
	}
	
	public String toString() {
		return super.toString() + precedingElement + " must precede " + element + " (see Figure 2).";
	}
}
