package org.xesstandard.xml.issues;

import org.xesstandard.model.XesAttribute;
import org.xesstandard.model.XesClassifier;
import org.xesstandard.model.XesEvent;
import org.xesstandard.model.XesExtension;
import org.xesstandard.model.XesGlobal;
import org.xesstandard.model.XesLog;
import org.xesstandard.model.XesTrace;
import org.xesstandard.model.XesValues;
import org.xesstandard.xml.XesXmlIssueLevel;

public class XesXmlIssueStrictlyConformingAttribute extends XesAbstractXmlIssue {

	/**
	 * Issue raised when some element contains an attribute that is not a XES attribute.
	 */
	private Object object;
	private String key;
	private String label;
	private String clause;
	
	public XesXmlIssueStrictlyConformingAttribute(XesLog log, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = log;
		label = "Log";
		clause = "Clause 5.1.2";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesTrace trace, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = trace;
		label = "Trace";
		clause = "Clause 5.2.2";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesEvent event, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = event;
		label = "Event";
		clause = "Clause 5.3.2";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesAttribute attribute, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = attribute;
		label = "Attribute";
		clause = "Clause 5.4.3 or Clause 5.4.4";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesExtension extension, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = extension;
		label = "Extension";
		clause = "Clause 5.5.2";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesGlobal global, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = global;
		label = "Global";
		clause = "Clause 5.6.2";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesClassifier classifier, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = classifier;
		label = "Classifier";
		clause = "Clause 5.7.2";
	}
	
	public XesXmlIssueStrictlyConformingAttribute(XesValues values, String tag) {
		super(XesXmlIssueLevel.STRICTLYCONFORMING);
		this.key = tag;
		this.object = values;
		label = "Values";
		clause = "Figure 2";
	}
	
	public String toString() {
		return super.toString() + "Attribute " + key + " is not a XES attribute (see " + clause + ").";
	}
}
