package org.xesstandard.xml.issues;

import org.xesstandard.model.XesExtension;
import org.xesstandard.xml.XesXmlIssueLevel;
import org.xml.sax.Locator;

public abstract class XesextAbstractXmlIssue extends XesAbstractXmlIssue {

	/**
	 * Abstract issue
	 */

	/**
	 * Line number and column number where the issue was raised.
	 */
	private int line, col;

	private String uriName;
	/**
	 * Level of the issue.
	 */
	private XesXmlIssueLevel level;

	/**
	 * Construct the issue with the given level.
	 * 
	 * @param level
	 *            The given level.
	 */
	public XesextAbstractXmlIssue(XesExtension extension, XesXmlIssueLevel level) {
		super(level);
		if (extension.getURI() != null) {
			uriName = extension.getURI().toString();
		} else {
			uriName = "<no URI>";
		}
		this.level = level;
	}

	/**
	 * Set the line number and column number where the issue was raised.
	 */
	public void setLocation(Locator locator) {
		line = locator.getLineNumber();
		col = locator.getColumnNumber();
	}

	/**
	 * @param level
	 *            The lowest error level.
	 * @return Whether this issue is an error.
	 */
	public boolean isError(XesXmlIssueLevel level) {
		return this.level.getValue() >= level.getValue();
	}

	public String toString() {
		return "File " + uriName + ", line " + line + ", column " + col + ": ";
	}
}
